==> kubernetes-model-admissionregistration-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/ValidatingAdmissionPolicyListFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingAdmissionPolicyListFluent<A extends ValidatingAdmissionPolicyListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ValidatingAdmissionPolicy item);
  public A setToItems(Integer index,ValidatingAdmissionPolicy item);
  public A addToItems(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ValidatingAdmissionPolicy... items);
  public A addAllToItems(Collection<ValidatingAdmissionPolicy> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ValidatingAdmissionPolicy... items);
  public A removeAllFromItems(Collection<ValidatingAdmissionPolicy> items);
  public A removeMatchingFromItems(Predicate<ValidatingAdmissionPolicyBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ValidatingAdmissionPolicy> getItems();
  public List<ValidatingAdmissionPolicy> buildItems();
  public ValidatingAdmissionPolicy buildItem(Integer index);
  public ValidatingAdmissionPolicy buildFirstItem();
  public ValidatingAdmissionPolicy buildLastItem();
  public ValidatingAdmissionPolicy buildMatchingItem(Predicate<ValidatingAdmissionPolicyBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ValidatingAdmissionPolicyBuilder> predicate);
  public A withItems(List<ValidatingAdmissionPolicy> items);
  public A withItems(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ValidatingAdmissionPolicy... items);
  public Boolean hasItems();
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> addNewItem();
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> addNewItemLike(ValidatingAdmissionPolicy item);
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> setNewItemLike(Integer index,ValidatingAdmissionPolicy item);
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> editItem(Integer index);
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> editFirstItem();
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> editLastItem();
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> editMatchingItem(Predicate<ValidatingAdmissionPolicyBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ValidatingAdmissionPolicyFluent<ValidatingAdmissionPolicyListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-admissionregistration-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/ValidatingAdmissionPolicyListFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ValidatingAdmissionPolicyListFluent<A extends ValidatingAdmissionPolicyListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ValidatingAdmissionPolicy item);
  public A setToItems(int index,ValidatingAdmissionPolicy item);
  public A addToItems(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ValidatingAdmissionPolicy... items);
  public A addAllToItems(Collection<ValidatingAdmissionPolicy> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ValidatingAdmissionPolicy... items);
  public A removeAllFromItems(Collection<ValidatingAdmissionPolicy> items);
  public A removeMatchingFromItems(Predicate<ValidatingAdmissionPolicyBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ValidatingAdmissionPolicy> getItems();
  public List<ValidatingAdmissionPolicy> buildItems();
  public ValidatingAdmissionPolicy buildItem(int index);
  public ValidatingAdmissionPolicy buildFirstItem();
  public ValidatingAdmissionPolicy buildLastItem();
  public ValidatingAdmissionPolicy buildMatchingItem(Predicate<ValidatingAdmissionPolicyBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ValidatingAdmissionPolicyBuilder> predicate);
  public A withItems(List<ValidatingAdmissionPolicy> items);
  public A withItems(io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1.ValidatingAdmissionPolicy... items);
  public Boolean hasItems();
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> addNewItem();
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> addNewItemLike(ValidatingAdmissionPolicy item);
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> setNewItemLike(int index,ValidatingAdmissionPolicy item);
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> editItem(int index);
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> editFirstItem();
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> editLastItem();
  public ValidatingAdmissionPolicyListFluent.ItemsNested<A> editMatchingItem(Predicate<ValidatingAdmissionPolicyBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ValidatingAdmissionPolicyFluent<ValidatingAdmissionPolicyListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
